@@ -1,6 +1,6 @@
 # --
 # Kernel/System/SupportDataCollector/Plugin/OS/Swap.pm - system data collector plugin
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,6 +14,8 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+our @ObjectDependencies = ();
+
 sub GetDisplayPath {
     return 'Operating System';
 }
@@ -87,7 +89,7 @@ sub Run {
                 );
             }
 
-            my $SwapUsed = $SwapTotal - $SwapFree;
+            my $SwapUsed = ( $SwapTotal - $SwapFree ) / 1024;
 
             if ( $SwapUsed > 200 ) {
                 $Self->AddResultProblem(
